@@ -1,6 +1,6 @@
-#-*- coding: utf-8 -*-
+# -*- coding: utf-8 -*-
 
-# Copyright 2011-2013 Calculate Ltd. http://www.calculate-linux.org
+# Copyright 2011-2015 Calculate Ltd. http://www.calculate-linux.org
 #
 #  Licensed under the Apache License, Version 2.0 (the "License");
 #  you may not use this file except in compliance with the License.
@@ -13,18 +13,21 @@
 #  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
+
 from itertools import cycle
 from calculate.lib.utils.colortext import get_terminal_print, Terminal, \
     TextState, convert_xml_to_terminal, Print
 from calculate.lib.cl_progressbar import get_progress_bar
 import sys
-from calculate.lib.utils.files import getch, set_active_tty
+from calculate.lib.utils.files import getch, set_active_tty, get_active_tty
 from calculate.lib.utils.text import tableReport
 import threading
 from calculate.lib.utils.tools import classificate
 
 Colors = TextState.Colors
 from calculate.lib.cl_lang import setLocalTranslate
+
+_ = lambda x: x
 setLocalTranslate('cl_core3', sys.modules[__name__])
 
 
@@ -74,35 +77,36 @@ class Table(tableReport):
 def printTable(data, header=None):
     try:
         return Table(None, header, data, colSpan=0).printTable()
-    except Exception as e:
-        print str(e)
+    except Exception:
+        # TODO: DEBUG
+        # print str(e)
         raise
 
 
+def echo_on(f):
+    def wrapper(self, *args, **kw):
+        oldecho = self.parent.terminal_info.echo
+        self.parent.terminal_info.echo = True
+        try:
+            return f(self, *args, **kw)
+        finally:
+            self.parent.terminal_info.echo = oldecho
+
+    return wrapper
+
+
 class TaskState(object):
     """
     Текущее состояние вывода сообщений
     """
+
     def __init__(self, parent):
-        """
-        @type parent: ResultViewer
-        """
         self.parent = parent
 
     @property
     def state(self):
         return self.parent.task_state
 
-    def echo_on(f):
-        def wrapper(self, *args, **kw):
-            oldecho = self.parent.terminal_info.echo
-            self.parent.terminal_info.echo = True
-            try:
-                return f(self, *args, **kw)
-            finally:
-                self.parent.terminal_info.echo = oldecho
-        return wrapper
-
     def process_tags(self, s):
         """
         Выполнить текстовое преобразование
@@ -124,7 +128,7 @@ class TaskState(object):
         """
         if width > 0:
             self.parent.printer('\r')
-            self.parent.printer.right(width-indent)
+            self.parent.printer.right(width - indent)
         else:
             self.parent.printer(" ")
 
@@ -142,7 +146,7 @@ class TaskState(object):
     def _print_result(self, text, color):
         width = self.parent.terminal_info.width
         self._change_asterisk(color, width)
-        self._right_indent(len(text)+4, width)
+        self._right_indent(len(text) + 4, width)
         self.parent.printer.bold.foreground(TextState.Colors.BLUE)("[ ")
         self.parent.printer.bold.foreground(color)(text)
         self.parent.printer.bold.foreground(TextState.Colors.BLUE)(" ]")
@@ -222,7 +226,7 @@ class TaskState(object):
                 no = _print.foreground(no_color)("No")
                 white_message = _print.foreground(Colors.WHITE)(message)
                 ask = raw_input(white_message + ' (%s/%s): ' % (yes, no))
-            except (EOFError,KeyboardInterrupt):
+            except (EOFError, KeyboardInterrupt):
                 ask = 'no'
                 print
             if ask.lower() in ['n', 'no']:
@@ -247,47 +251,47 @@ class TaskState(object):
         printer = self.parent.printer
         _print = Print(output=printer.output)
         # ability answer by first letter
-        FIRSTLETTER = 0
-        VALUE, COMMENT = 0, 1
-        answerByChar = map(lambda x: x[VALUE][FIRSTLETTER], answers)
+        firstletter = 0
+        i_value, i_comment = 0, 1
+        answerByChar = map(lambda x: x[i_value][firstletter], answers)
 
         if filter(lambda x: answerByChar.count(x) > 1, answerByChar):
             use_getch = False
-            sa = slice(None)
+            sa = slice(0, None)
         else:
             use_getch = True
             sa = slice(1)
         message = _print.foreground(Colors.WHITE)(message)
-        full_message = message + ' (%s): ' % \
-                       ("/".join(map(lambda x: \
-                                         "%s[%s]" % (x[COMMENT], x[VALUE][sa]),
-                                     answers)))
+        full_message = (message +
+                        ' (%s): ' % ("/".join(map(
+                            lambda x: "%s[%s]" % (x[i_comment], x[i_value][sa]),
+                            answers))))
         while True:
             CTRC_C = chr(3)
             if use_getch:
                 printer(full_message)
                 ask = getch()
                 printer("\n")
-                if ask in (CTRC_C,""):
+                if ask in (CTRC_C, ""):
                     raise KeyboardInterrupt
             else:
                 try:
                     ask = raw_input(full_message)
-                except (EOFError,KeyboardInterrupt):
+                except (EOFError, KeyboardInterrupt):
                     printer("\n")
                     raise KeyboardInterrupt
             ask = ask.lower()
-            like_answers = filter(lambda x: x[VALUE].startswith(ask),
+            like_answers = filter(lambda x: x[i_value].startswith(ask),
                                   answers)
             if not like_answers:
                 self.state.printERROR(_('The answer is uncertain'))
                 continue
             if len(like_answers) == 1:
-                return like_answers[VALUE][FIRSTLETTER]
+                return like_answers[i_value][firstletter]
             else:
                 self.state.printERROR(_('Ambiguous answer:') +
-                                       ",".join(map(lambda x: x[COMMENT],
-                                                    like_answers)))
+                                      ",".join(map(lambda x: x[i_comment],
+                                                   like_answers)))
 
     @echo_on
     def askQuestion(self, message):
@@ -296,25 +300,32 @@ class TaskState(object):
 
     def askPassword(self, message, twice):
         from calculate.lib.utils.common import getpass
-        if self.parent.terminal_info.is_boot_console():
-            set_active_tty(1)
 
-        text1 = _("%s: ") % message
-        if not twice:
-            return getpass.getpass(text1)
-        text2 = _('Repeat: ')
-        pass1 = 'password'
-        pass2 = 'repeat'
+        old_tty = None
         try:
-            while pass1 != pass2:
-                pass1 = getpass.getpass(text1)
-                pass2 = getpass.getpass(text2)
-                if pass1 != pass2:
-                    self.state.printERROR(_('Passwords do not match'))
-        except KeyboardInterrupt:
-            return None
-        passwd = pass1 if (pass1 and pass1 == pass2) else None
-        return passwd
+            if self.parent.terminal_info.is_boot_console():
+                old_tty = get_active_tty()
+                set_active_tty(1)
+
+            text1 = _("%s: ") % message
+            if not twice:
+                return getpass.getpass(text1)
+            text2 = _('Repeat: ')
+            pass1 = 'password'
+            pass2 = 'repeat'
+            try:
+                while pass1 != pass2:
+                    pass1 = getpass.getpass(text1)
+                    pass2 = getpass.getpass(text2)
+                    if pass1 != pass2:
+                        self.state.printERROR(_('Passwords do not match'))
+            except KeyboardInterrupt:
+                return None
+            passwd = pass1 if (pass1 and pass1 == pass2) else None
+            return passwd
+        finally:
+            if old_tty and old_tty.isdigit():
+                set_active_tty(int(old_tty))
 
     def printTable(self, table_name, head, body):
         self.state.printSUCCESS(message=table_name)
@@ -325,6 +336,7 @@ class CleanState(TaskState):
     """
     Ожидается вывод
     """
+
     def startTask(self, message, progress, num):
         self.printMessage(Colors.GREEN, message)
         self.parent.spinner = Spinner()
@@ -349,6 +361,7 @@ class CleanStateNoProgress(CleanState):
     """
     ... без отображения прогрессов
     """
+
     def startTask(self, message, progress, num):
         self.display_asterisk(Colors.GREEN)
         self.parent.printer(message)
@@ -360,6 +373,7 @@ class StartState(TaskState):
     """
     Выполняется задача (отображается spinner)
     """
+
     def startTask(self, message, progress, num):
         self.parent.endTask(True)
         self.parent.startTask(message, progress, num)
@@ -443,6 +457,7 @@ class StartStateNoProgress(StartState):
     """
     ... без прогресса
     """
+
     def startTask(self, message, progress, num):
         self.parent.endTask(True)
         self.parent.startTask(message, progress, num)
@@ -477,6 +492,7 @@ class BreakedState(StartState):
     """
     Во время выполнения задачи выведено сообщение
     """
+
     def stop_spinner_newline(self):
         self.parent.spinner.stop()
         self.parent.printer('\n')
@@ -511,6 +527,7 @@ class PreProgressState(StartState):
     """
     Задача запрошена как с прогрессом но проценты еще не обрабатывались
     """
+
     def addProgress(self, message):
         pass
 
@@ -527,6 +544,7 @@ class ProgressState(StartState):
     """
     Отображается progressbar
     """
+
     def finish_and_clean(self):
         self.parent.printer('\r')
         self.parent.printer.flush()
@@ -573,6 +591,7 @@ class ResultViewer(object):
     """
     Просмотрщик результатов
     """
+
     def __init__(self):
         self.printer = \
             get_terminal_print(sys.stdout)
