@@ -67,7 +67,7 @@ class BoolAction(argparse.Action):
 
 
 def _print(*args):
-    print " ".join(map(lambda x: unicode(x).encode('utf-8'), args))
+    print " ".join(map(lambda x: _u8(x), args))
 
 
 def get_password(text1=None, text2=None, getfromstdin=False,
@@ -130,20 +130,20 @@ def _getattr(obj, attr):
 
 import argparse
 import textwrap as _textwrap
-from calculate.lib.utils.text import getTerminalSize
+from calculate.lib.utils.text import get_term_size, _u, _u8
 
 
 class RawAndDefaultsHelpFormatter(argparse.HelpFormatter):
     def __init__(self, prog, max_help_position=24, **kwargs):
         # Use the whole terminal width
-        height, width = getTerminalSize()
+        height, width = get_term_size()
         argparse.HelpFormatter.__init__(self, prog, width=width,
                                         max_help_position=max_help_position,
                                         **kwargs)
 
     def _split_lines(self, text, width):
-        text = self._whitespace_matcher.sub(' ', text.decode('utf-8')).strip()
-        return _textwrap.wrap(text.decode('utf-8'), width)
+        text = self._whitespace_matcher.sub(' ', _u(text)).strip()
+        return _textwrap.wrap(_u(text), width)
 
 
 def get_method_argparser(view, args, cl_core=False):
@@ -279,10 +279,10 @@ def set_obj_item(client, param_object, field_name, value):
 def set_table_pwd(client, param_object, field, value):
     if type(field.tablevalue.values) in [list, tuple]:
         choice_values = field.tablevalue.values
-    #        column = len(field.tablevalue.head)
+    # column = len(field.tablevalue.head)
     else:
         choice_values = field.tablevalue.values.ChoiceValue
-    #        column = len(field.tablevalue.head.string)
+    # column = len(field.tablevalue.head.string)
     #    print ChoiceValue, column
     found_flag = False
     changed_string = None
@@ -386,7 +386,7 @@ def display_error(error, args, groups):
                 if field.name == error.field:
                     if args is not None:
                         if (getattr(args, field.name) == "list" and
-                                "choice" in field.type):
+                                    "choice" in field.type):
                             if error.field_obj:
                                 list_answer = True
                                 varname = (error.field_obj.label or
@@ -452,9 +452,9 @@ def check_result_msg(method_result, view, input_error_dict=None, args=None):
     # если все ошибки связаны с паролем
     if len(password_errors) == len(method_result):
         if (not dict([x for x in input_error_dict.items()
-                     if x not in password_errors.items()]) and
-            not dict([x for x in password_errors.items()
-                     if x not in input_error_dict.items()])):
+                      if x not in password_errors.items()]) and
+                not dict([x for x in password_errors.items()
+                          if x not in input_error_dict.items()])):
             return None
         return password_errors
     else:
@@ -497,7 +497,7 @@ def collect_object(client, param_object, view, args, wait_thread=None,
             if field.uncompatible:
                 continue
             if (field.element in ['check', 'check_tristate'] and
-                    field.type == 'bool'):
+                        field.type == 'bool'):
                 set_flag = False
                 if not set_flag:
                     value = _getattr(args, field.name)
@@ -519,13 +519,13 @@ def collect_object(client, param_object, view, args, wait_thread=None,
                                             _getattr(args, field.name))
 
             elif (field.element == 'input' and
-                  field.name in ['cl_page_offset', 'cl_page_count']):
+                          field.name in ['cl_page_offset', 'cl_page_count']):
                 val = _getattr(args, field.name)
                 if not val:
                     val = 0
                 if wait_thread:
                     wait_thread.stop()
-                #                param_object[field.name] = val
+                # param_object[field.name] = val
                 param_object = set_obj_item(client, param_object, field.name,
                                             val)
 
@@ -627,7 +627,7 @@ def collect_table(field, val_list, client, wait_thread=None,
                          (field.opt.shortopt or field.opt.longopt)
                          + " " + wrong)
 
-    #    obj_body = []
+    # obj_body = []
 
     #    if type(field.tablevalue.body) == list:
     #        temp_body = field.tablevalue.body
